==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDNSSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkDNSSpecFluent<A extends NetworkDNSSpecFluent<A>> extends BaseFluent<A>{
  public NetworkDNSSpecFluent() {
  }
  public NetworkDNSSpecFluent(NetworkDNSSpec instance) {
    instance = (instance != null ? instance : new NetworkDNSSpec());

    if (instance != null) {
      this.withDnsDomainName(instance.getDnsDomainName());
      this.withDnsIp(instance.getDnsIp());
      this.withDnsServer(instance.getDnsServer());
      this.withDnsDomainName(instance.getDnsDomainName());
      this.withDnsIp(instance.getDnsIp());
      this.withDnsServer(instance.getDnsServer());
    }
  }
  private String dnsDomainName;
  private String dnsIp;
  private String dnsServer;
  public String getDnsDomainName() {
    return this.dnsDomainName;
  }
  public A withDnsDomainName(String dnsDomainName) {
    this.dnsDomainName=dnsDomainName; return (A) this;
  }
  public boolean hasDnsDomainName() {
    return this.dnsDomainName != null;
  }
  public String getDnsIp() {
    return this.dnsIp;
  }
  public A withDnsIp(String dnsIp) {
    this.dnsIp=dnsIp; return (A) this;
  }
  public boolean hasDnsIp() {
    return this.dnsIp != null;
  }
  public String getDnsServer() {
    return this.dnsServer;
  }
  public A withDnsServer(String dnsServer) {
    this.dnsServer=dnsServer; return (A) this;
  }
  public boolean hasDnsServer() {
    return this.dnsServer != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDNSSpecFluent that = (NetworkDNSSpecFluent) o;
    if (!java.util.Objects.equals(dnsDomainName, that.dnsDomainName)) return false;

    if (!java.util.Objects.equals(dnsIp, that.dnsIp)) return false;

    if (!java.util.Objects.equals(dnsServer, that.dnsServer)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dnsDomainName,  dnsIp,  dnsServer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dnsDomainName != null) { sb.append("dnsDomainName:"); sb.append(dnsDomainName + ","); }
    if (dnsIp != null) { sb.append("dnsIp:"); sb.append(dnsIp + ","); }
    if (dnsServer != null) { sb.append("dnsServer:"); sb.append(dnsServer); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDNSSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkDNSSpecFluent<A extends NetworkDNSSpecFluent<A>> extends BaseFluent<A>{
  public NetworkDNSSpecFluent() {
  }
  
  public NetworkDNSSpecFluent(NetworkDNSSpec instance) {
    this.copyInstance(instance);
  }
  private String dnsDomainName;
  private String dnsIp;
  private String dnsServer;
  
  protected void copyInstance(NetworkDNSSpec instance) {
    instance = (instance != null ? instance : new NetworkDNSSpec());
  
    if (instance != null) {
        this.withDnsDomainName(instance.getDnsDomainName());
        this.withDnsIp(instance.getDnsIp());
        this.withDnsServer(instance.getDnsServer());
        this.withDnsDomainName(instance.getDnsDomainName());
        this.withDnsIp(instance.getDnsIp());
        this.withDnsServer(instance.getDnsServer());
      }
  }
  
  public String getDnsDomainName() {
    return this.dnsDomainName;
  }
  
  public A withDnsDomainName(String dnsDomainName) {
    this.dnsDomainName=dnsDomainName; return (A) this;
  }
  
  public boolean hasDnsDomainName() {
    return this.dnsDomainName != null;
  }
  
  public String getDnsIp() {
    return this.dnsIp;
  }
  
  public A withDnsIp(String dnsIp) {
    this.dnsIp=dnsIp; return (A) this;
  }
  
  public boolean hasDnsIp() {
    return this.dnsIp != null;
  }
  
  public String getDnsServer() {
    return this.dnsServer;
  }
  
  public A withDnsServer(String dnsServer) {
    this.dnsServer=dnsServer; return (A) this;
  }
  
  public boolean hasDnsServer() {
    return this.dnsServer != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDNSSpecFluent that = (NetworkDNSSpecFluent) o;
    if (!java.util.Objects.equals(dnsDomainName, that.dnsDomainName)) return false;
  
    if (!java.util.Objects.equals(dnsIp, that.dnsIp)) return false;
  
    if (!java.util.Objects.equals(dnsServer, that.dnsServer)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(dnsDomainName,  dnsIp,  dnsServer,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dnsDomainName != null) { sb.append("dnsDomainName:"); sb.append(dnsDomainName + ","); }
    if (dnsIp != null) { sb.append("dnsIp:"); sb.append(dnsIp + ","); }
    if (dnsServer != null) { sb.append("dnsServer:"); sb.append(dnsServer); }
    sb.append("}");
    return sb.toString();
  }
  

}
